==> classiq-0.1.11.tar.gz: classiq-0.1.11/classiq/authentication/token_manager.py <==
import argparse
from typing import Optional

from classiq.authentication import auth0, password_manager as pm


class TokenManager:
    def __init__(self):
        self._access_token = None
        self._refresh_token = None

        parser = argparse.ArgumentParser()
        parser.add_argument(
            "--skip-authentication", action="store_true", required=False
        )
        args, _ = parser.parse_known_args()

        self._password_manager: pm.PasswordManager = (
            pm.PasswordManager()
            if not args.skip_authentication
            else pm.DummyPasswordManager()
        )

    @property
    def access_token(self) -> str:
        if self._access_token:
            return self._access_token

        if (access_token := self._password_manager.access_token) is not None:
            self._access_token = access_token
            return access_token

        self._access_token = self._refresh_access_token(
            refresh_token=self._refresh_token
        )
        self._password_manager.access_token = self._access_token
        return self._access_token

    def update_expired_access_token(self) -> None:
        refresh_token = self._refresh_token
        if refresh_token is None:
            refresh_token = self._password_manager.refresh_token

        self._access_token = self._refresh_access_token(refresh_token=refresh_token)
        self._password_manager.access_token = self._access_token

    @classmethod
    def _refresh_access_token(cls, refresh_token: str) -> str:
        data = auth0.Auth0.refresh_access_token(refresh_token)

        return data["access_token"]

    def save_tokens(self, access_token: str, refresh_token: Optional[str]) -> None:
        self._access_token = access_token
        self._password_manager.access_token = access_token
        self._refresh_token = refresh_token
        self._password_manager.refresh_token = refresh_token

    def is_refresh_token_available(self) -> bool:
        if self._refresh_token is not None:
            return True

        self._refresh_token = self._password_manager.refresh_token
        return self._refresh_token is not None

==> classiq-0.1.14-1.tar.gz: classiq-0.1.14/classiq/authentication/token_manager.py <==
import argparse
from typing import Optional

from loguru import logger

from classiq.authentication import auth0, password_manager as pm


class TokenManager:
    def __init__(self):
        self._access_token = None
        self._refresh_token = None

        parser = argparse.ArgumentParser()
        parser.add_argument(
            "--skip-authentication", action="store_true", required=False
        )
        args, _ = parser.parse_known_args()

        self._password_manager: pm.PasswordManager = (
            pm.PasswordManager()
            if not args.skip_authentication
            else pm.DummyPasswordManager()
        )

    @property
    def access_token(self) -> Optional[str]:
        if self._access_token:
            return self._access_token

        if (access_token := self._password_manager.access_token) is not None:
            self._access_token = access_token
            return access_token

        if self._refresh_token is None:
            logger.debug("Can't produce access token without refresh token")
            return None

        self._access_token = self._refresh_access_token(
            refresh_token=self._refresh_token
        )
        self._password_manager.access_token = self._access_token
        return self._access_token

    def update_expired_access_token(self) -> None:
        refresh_token = self._refresh_token
        if refresh_token is None:
            refresh_token = self._password_manager.refresh_token

        self._access_token = self._refresh_access_token(refresh_token=refresh_token)
        self._password_manager.access_token = self._access_token

    @classmethod
    def _refresh_access_token(cls, refresh_token: str) -> str:
        data = auth0.Auth0.refresh_access_token(refresh_token)

        return data["access_token"]

    def save_tokens(self, access_token: str, refresh_token: Optional[str]) -> None:
        self._access_token = access_token
        self._password_manager.access_token = access_token
        self._refresh_token = refresh_token
        self._password_manager.refresh_token = refresh_token

    def is_refresh_token_available(self) -> bool:
        if self._refresh_token is not None:
            return True

        self._refresh_token = self._password_manager.refresh_token
        return self._refresh_token is not None
